@@ -1,9 +1,13 @@
 # -*- coding: utf-8 -*-
 
-
+from ocp_resources.constants import TIMEOUT_4MINUTES
+from ocp_resources.logger import get_logger
 from ocp_resources.resource import NamespacedResource
 
 
+LOGGER = get_logger(name=__name__)
+
+
 class PersistentVolumeClaim(NamespacedResource):
     """
     PersistentVolumeClaim object
@@ -43,6 +47,8 @@ class PersistentVolumeClaim(NamespacedResource):
         hostpath_node=None,
         teardown=True,
         yaml_file=None,
+        delete_timeout=TIMEOUT_4MINUTES,
+        **kwargs,
     ):
         super().__init__(
             name=name,
@@ -50,6 +56,8 @@ class PersistentVolumeClaim(NamespacedResource):
             client=client,
             teardown=teardown,
             yaml_file=yaml_file,
+            delete_timeout=delete_timeout,
+            **kwargs,
         )
         self.accessmodes = accessmodes
         self.volume_mode = volume_mode
@@ -93,7 +101,7 @@ class PersistentVolumeClaim(NamespacedResource):
         Returns:
             bool: True if bound else False
         """
-        self.logger.info(f"Check if {self.kind} {self.name} is bound")
+        LOGGER.info(f"Check if {self.kind} {self.name} is bound")
         return self.status == self.Status.BOUND
 
     @property
